@@ -20,16 +20,29 @@ gim.default <- function(formula, family, data, model,
     tol <- argu$tol
   }
   
+  if(is.null(argu$silent)){
+    silent <- TRUE
+  }else{
+    silent <- FALSE
+  }
+  
   data <- clean.data(data)
   
-  fp <- formula.parse(formula, model, data, ref)
+  cm <- collapse.model(family, model, nsample, ncase, nctrl)
+  model <- cm$model
+  nsample <- cm$nsample
+  ncase <- cm$ncase
+  nctrl <- cm$nctrl
+  
+  fp <- formula.parse(formula, family, data, model, ref)
   model <- fp$model
   data <- fp$data
   ref <- fp$ref
   outcome <- fp$outcome
-  formula <- fp$formula
+  fit0 <- fp$fit0
+  type <- fp$type
   
-  ini <- init(formula, family, data, model, nsample, ncase, nctrl, outcome)
+  ini <- init(fit0, family, data, ref, model, nsample, ncase, nctrl, outcome, type)
   para <- ini$para
   map <- ini$map
   bet0 <- ini$bet0
@@ -41,19 +54,20 @@ gim.default <- function(formula, family, data, model,
   
   while(niter > 0){
     #message('Running Newton-Raphson algorithm on first stage...')
-    V <- optimal.Sigma0(para, map, family, ref, model, sample.info, pr0, Delta, outcome)
+    V <- optimal.Sigma0(para, map, family, ref, model, sample.info, pr0, Delta, outcome, type, bet0)
     if(eps < tol){
       break
     }
-    fit <- NR(para, map, family, data, ref, V, bet0, sample.info, outcome)
+    fit <- NR(para, map, family, data, ref, V, bet0, sample.info, outcome, type, silent)
+    #fit <- loop(para, map, family, data, ref, V, bet0, sample.info, outcome, type, silent)
     eps <- max(abs(para - fit$coefficients))
     para <- fit$coefficients
     niter <- niter - 1
   }
   
-  fit$vcov <- mcov(para, map, family, data, ref, model, sample.info, V, bet0, outcome)
+  fit$vcov <- mcov(para, map, family, data, ref, model, sample.info, V, bet0, outcome, type)
   
-  fit <- reorganize(fit, map, family)
+  fit <- reorganize(fit, map, family, type)
   
   fit$call <- match.call()
   fit$V.bet <- V
