@@ -7,7 +7,7 @@
 # bet0 := summary statistics to be used in quadratic form
 
 
-init.lo <- function(formula, data, model, nsample){
+init.lo <- function(fit0, data, model, nsample){
   
   #message('Initializing integration analysis...')
   
@@ -18,7 +18,7 @@ init.lo <- function(formula, data, model, nsample){
   
   nsample <- as.matrix(nsample)
   
-  fit0 <- glm(formula, data = data, family = 'binomial')
+  #fit0 <- glm(formula, data = data, family = 'binomial')
   the <- coef(fit0)
   
   n <- nrow(data)
@@ -36,11 +36,18 @@ init.lo <- function(formula, data, model, nsample){
   for(i in 1:nmodel){
     
     form <- model[[i]][[1]]
-    fit <- glm(form, data = data, family = 'binomial')
+    #fit <- glm(form, data = data, family = 'binomial')
+    fit <- model[[i]][[4]]
     alp.var <- as.character(model[[i]][[2]])
     bet.var <- as.character(model[[i]][[3]]$var) # critical for meta-analysis of bet below
     N <- diag(nsample)[i]
-    alp0 <- coef(fit)[alp.var]
+    
+    if(length(alp.var) > 0){
+      alp0 <- coef(fit)[alp.var]
+    }else{
+      alp0 <- NULL
+    }
+    
     meta.bet <- (n * coef(fit)[bet.var] + N * model[[i]][[3]]$bet) / (n + N)
     #meta.bet <- model[[i]][[3]]$bet
     names(meta.bet) <- model[[i]][[3]]$var
@@ -48,7 +55,7 @@ init.lo <- function(formula, data, model, nsample){
     bet <- c(bet, meta.bet)
     bet0 <- c(bet0, model[[i]][[3]]$bet)
     
-    if(length(alp0) > 0){
+    if(!is.null(alp0)){
       map$alp[[i + 1]] <- max(map$alp[[i]]) + 1:length(alp0)
     }else{
       map$alp[[i + 1]] <- map$alp[[i]]
@@ -77,18 +84,20 @@ init.lo <- function(formula, data, model, nsample){
   all.alp <- NULL
   all.bet <- NULL
   for(i in 1:nmodel){
-    map$alp[[i]] <- map$alp[[i]] + nlam + nthe
+    if(i %in% no.alp){
+      map$alp[[i]] <- NA
+    }else{
+      map$alp[[i]] <- map$alp[[i]] + nlam + nthe
+      all.alp <- c(all.alp, map$alp[[i]])
+    }
     map$bet[[i]] <- map$bet[[i]] + nlam + nthe + nalp
-    all.alp <- c(all.alp, map$alp[[i]])
     all.bet <- c(all.bet, map$bet[[i]])
   }
-  if(!is.null(no.alp)){
-    for(i in no.alp){
-      map$alp[[i]] <- NA
-    }
+  
+  if(!is.null(all.alp)){
+    map$all.alp <- sort(unique(all.alp))
   }
   
-  map$all.alp <- sort(unique(all.alp))
   map$all.bet <- sort(unique(all.bet))
   
   list(para = para, map = map, bet0 = bet0, sample.info = nsample)
